﻿Imports System.Collections.ObjectModel
Imports System.Drawing.Printing
Imports ThinkGeo.MapSuite.WinForms
Imports ThinkGeo.MapSuite.Layers
Imports ThinkGeo.MapSuite.Shapes
Imports ThinkGeo.MapSuite
Imports ThinkGeo.MapSuite.Styles
Imports ThinkGeo.MapSuite.Drawing

Public Class Form1
    Private WithEvents moPrinterOverlay As PrinterInteractiveOverlay
    Private moPrinterPage As CustomPagePrinterLayer
    Private moPageLayoutMap As MapPrinterLayer
    Private moShapefile As ShapeFileFeatureLayer
    Private moScaleBarLayer As ScaleBarPrinterLayer
    Private moScaleLineLayer As ScaleLinePrinterLayer
    Private moScaleTextLayer As ScaleTextPrinterLayer
    Private moMyScaleTextLayer As MyScaleTextPrinterLayer
    Private moFeatureExtent As RectangleShape

    Public Enum EnumPagePosition
        TopLeft = 1
        TopRight = 2
        LowerLeft = 3
        LowerRight = 4
    End Enum
    Public Enum EnumCenterType
        Horizontal = 1
        Vertical = 2
    End Enum
    Public Shared Property ScaleDisplayMethod As MyScaleTextPrinterLayer.EnumScaleDisplayMethod = MyScaleTextPrinterLayer.EnumScaleDisplayMethod.InchesFeet

    Private Sub Form1_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        CreateDefaultLayout()
        btnProjected.Enabled = False
        btnGeographic.Enabled = True

        '***** Load the position combo box
        'cboPosition.Items.Add("Top Left")
        'cboPosition.Items.Add("Top Right")
        'cboPosition.Items.Add("Lower Left")
        'cboPosition.Items.Add("Lower Right")

        cboPosition.Items.Add("Vertically")
        cboPosition.Items.Add("Horizontally")

        cboPosition.SelectedIndex = 0


        Dim sInstructions As String =
           "1. Set the scale to 1320 ft/in by clicking on the button." & ControlChars.CrLf &
           "2. Make sure the coordinate system units are in Meters, which it shoud be when the project starts." & ControlChars.CrLf &
           "3. Print the map." & ControlChars.CrLf &
           "4. Measure a side of the sqare feature, it should be exactly four inches. Note that it is about 3 7/8 inches."

        TextBox1.Text = sInstructions

    End Sub

    Public Sub CreateDefaultLayout()
        Dim oExtentRectangle As RectangleShape

        moPrinterOverlay = New PrinterInteractiveOverlay()
        With PageLayout
            '***** Setup the map unit, you want to always use feet or meters for printer layout maps
            .MapUnit = GeographyUnit.Feet
            '***** Create the default zoom levels for the layout map
            .ZoomLevelSet = New PrinterZoomLevelSet(.MapUnit, PrinterHelper.GetPointsPerGeographyUnit(.MapUnit))

            '***** Set the background color to gray so there is contrast with the white page
            .BackgroundOverlay.BackgroundBrush = New GeoSolidBrush(GeoColor.StandardColors.LightGray)

            '***** Create the PrinterInteractiveOverlay to contain all of the PrinterLayers.
            '***** The interactive overlay allows the layers to be interacted with
            .InteractiveOverlays.Add("PrinterOverlay", moPrinterOverlay)
            .InteractiveOverlays.MoveToBottom("PrinterOverlay")

            '***** Create the PagePrinterLayer which shows the page boundary and 
            '***** is the area the user will arrange all of the other layers on top of.
            moPrinterPage = New CustomPagePrinterLayer(PrinterPageSize.AnsiA, PrinterOrientation.Portrait)
            With moPrinterPage
                .Open()
                .BackgroundMask = AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.White, GeoColor.SimpleColors.Black, 1)
                moPrinterOverlay.PrinterLayers.Add("PrinterPage", moPrinterPage)
                '***** Get the page's extent, scale it up by 10%
                oExtentRectangle = CType(RectangleShape.ScaleUp(.GetPosition(), 10), RectangleShape)
                '***** Set oExtentRectangle as the default current extent
            End With
            .CurrentExtent = oExtentRectangle

            '***** Set the minimum scale of the map to the last zoom level
            .MinimumScale = .ZoomLevelSet.ZoomLevel20.Scale

            '***** Add a container for the map layers
            AddMapLayerContainer()

            '***** Add a layer to the page layout
            AddMapLayer()

            '***** Add a scale line
            CreateDefaultScaleLine()

            '***** Add a scale bar
            CreateDefaultScaleBar()


            CreateDefaultScaleText()

            CreateMyDefaultScaleText()

            Try
                btnRefresh_Click(Nothing, Nothing)
            Catch ex As Exception

            End Try

        End With
    End Sub
    Public Sub AddMapLayer()

        moPageLayoutMap.MapUnit = GeographyUnit.Meter

        Dim sPath As String = "..\..\Data\NewPoly.shp"
        moShapefile = New ShapeFileFeatureLayer(sPath, GeoFileReadWriteMode.ReadWrite)
        moShapefile.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.SimpleColors.Red, 1)
        moShapefile.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20
        moPageLayoutMap.Layers.Add(moShapefile)
        moShapefile.Open()
        Dim oFeature As Feature = moShapefile.QueryTools.GetFeatureById("3", ReturningColumnsType.AllColumns)


        moFeatureExtent = oFeature.GetBoundingBox
        moFeatureExtent.ScaleUp(100)
        moPageLayoutMap.MapExtent = moFeatureExtent


    End Sub
    Public Function GetPrinter() As PrinterSettings
        Dim oPrintDialog As New PrintDialog
        Dim oPrinterSettings As PrinterSettings = Nothing

        With oPrintDialog
            If Not .ShowDialog() = DialogResult.Cancel Then
                oPrinterSettings = .PrinterSettings
            End If
        End With
        Return oPrinterSettings
    End Function

    Public Sub Print()

        '***** Get the printer for printing
        Dim oPrinterSettings As PrinterSettings = GetPrinter()
        If oPrinterSettings Is Nothing Then
            Return
        End If

        Dim oPrinterOverLay As PrinterInteractiveOverlay = moPrinterOverlay
        Dim oPagePrinterLayer As PagePrinterLayer = moPrinterPage

        Dim oPrintDocument As New PrintDocument()
        With oPrintDocument
            .PrinterSettings = oPrinterSettings
            .DefaultPageSettings.Landscape = True
            If oPagePrinterLayer.Orientation = PrinterOrientation.Portrait Then
                .DefaultPageSettings.Landscape = False
            End If
            .DefaultPageSettings.PaperSize = New PaperSize("AnsiA", CInt(850), CInt(1100))
        End With

        Dim oRect As RectangleShape
        Dim oNewUpperLeft As PointShape
        Dim oNewLowerRight As PointShape
        Dim oNewRect As RectangleShape

        Dim oPrinterCanvas As PrinterGeoCanvas = New PrinterGeoCanvas()

        '***** Create a rectangle to represent the drawing area for the document
        oPrinterCanvas.DrawingArea = New Rectangle(0, 0, 850, 1100)

        '***** Start the drawing process
        oPrinterCanvas.BeginDrawing(oPrintDocument, oPagePrinterLayer.GetBoundingBox(), PageLayout.MapUnit)

        '***** Loop through all of the PrintingLayers in the PrinterInteractiveOverlay 
        '***** and print all of the except for the PagePrinterLayer                
        Dim labelsInAllLayers As Collection(Of SimpleCandidate) = New Collection(Of SimpleCandidate)()
        For Each oPrinterLayer As PrinterLayer In oPrinterOverLay.PrinterLayers
            oPrinterLayer.IsDrawing = True
            If Not (TypeOf oPrinterLayer Is PagePrinterLayer) Then
                oPrinterLayer.Open()
                '***** Shift the PrinterLayer to the right and up by HardMarginX and HardMarginY
                oRect = (oPrinterLayer.GetPosition(PrintingUnit.Inch))
                oNewUpperLeft = New PointShape(oRect.UpperLeftPoint.X - 0.13, oRect.UpperLeftPoint.Y + 0.06)
                oNewLowerRight = New PointShape(oRect.LowerRightPoint.X - 0.13, oRect.LowerRightPoint.Y + 0.06)
                oNewRect = (New RectangleShape(oNewUpperLeft, oNewLowerRight))
                oPrinterLayer.SetPosition(oNewRect, PrintingUnit.Inch)
                oPrinterLayer.Draw(oPrinterCanvas, labelsInAllLayers)
                oPrinterLayer.SetPosition(oRect, PrintingUnit.Inch)
            End If
            oPrinterLayer.IsDrawing = False
        Next oPrinterLayer

        oPrinterCanvas.EndDrawing()




    End Sub
    Public Shared Function MapExtentFromScale(dScale As Double, oWorldExtent As RectangleShape, eWorldExtentUnit As GeographyUnit, oPageLayoutMap As MapPrinterLayer) As RectangleShape
        oPageLayoutMap.Open()
        Dim oPagePosition As RectangleShape = oPageLayoutMap.GetPosition
        Dim snglPageWidth As Single = CSng(oPagePosition.Width)
        Dim snglPageHeight As Single = CSng(oPagePosition.Height)
        Dim oExtent As RectangleShape

        oExtent = ExtentHelper.ZoomToScale(dScale, oWorldExtent, eWorldExtentUnit, snglPageWidth, snglPageHeight)
        Return oExtent

    End Function

    Public Sub SetScale()
        Dim dWidth As Single = CSng(moPageLayoutMap.GetPosition(PrintingUnit.Inch).Width * 96)
        Dim dHeight As Single = CSng(moPageLayoutMap.GetPosition(PrintingUnit.Inch).Height * 96)

        dWidth = CSng(moPageLayoutMap.GetPosition(PrintingUnit.Point).Width)
        dHeight = CSng(moPageLayoutMap.GetPosition(PrintingUnit.Point).Height)

        dWidth = CSng(moPageLayoutMap.GetBoundingBox.Width)
        dHeight = CSng(moPageLayoutMap.GetBoundingBox.Height)

        'Dim oExtent As RectangleShape = ExtentHelper.ZoomToScale(15840, moPageLayoutMap.MapExtent, moPageLayoutMap.MapUnit, dWidth, dHeight)
        Dim oExtent As RectangleShape = ExtentHelper.ZoomToGeodesicScale(15840, moPageLayoutMap.MapExtent, moPageLayoutMap.MapUnit, dWidth, dHeight)
        'oExtent = ExtentHelper.CenterAt(oExtent, moPageLayoutMap.MapExtent.GetCenterPoint, dWidth, dHeight)

        'oExtent = MapExtentFromScale(15840,  )

        'oExtent = mMapExtentFromScale(15840, moPageLayoutMap.MapExtent, moPageLayoutMap.MapUnit, moPageLayoutMap)
        oExtent = ExtentHelper.GetDrawingExtent(oExtent, dWidth, dHeight)

        moPageLayoutMap.MapExtent = oExtent
        btnRefresh_Click(Nothing, Nothing)
    End Sub
    Public Function mMapExtentFromScale(dScale As Double, oWorldExtent As RectangleShape, eWorldExtentUnit As GeographyUnit, oPageLayoutMap As MapPrinterLayer) As RectangleShape
        oPageLayoutMap.Open()
        Dim oPagePosition As RectangleShape = oPageLayoutMap.GetPosition
        Dim snglPageWidth As Single = CSng(oPagePosition.Width)
        Dim snglPageHeight As Single = CSng(oPagePosition.Height)
        Dim oExtent As RectangleShape

        oExtent = ExtentHelper.ZoomToScale(dScale, oWorldExtent, eWorldExtentUnit, snglPageWidth, snglPageHeight)
        'If eScaleMode = SilvicsPageLayout.EnumScaleMode.BestFit Then
        '  While oExtent.Width < oWorldExtent.Width Or oExtent.Height < oWorldExtent.Height
        '    oExtent.ScaleUp(5)
        '  End While
        'End If
        Return oExtent

    End Function

    Private Function mAddSquareMileFeature(moShapeFile As ShapeFileFeatureLayer) As PolygonShape
        Dim oStartVert As New Vertex(521045, 3544986)
        Dim oNewPoly As New PolygonShape
        Dim oVertices(4) As Vertex
        Dim oCols As New Dictionary(Of String, String)
        Const cdMILE_IN_METERS As Double = 1609.344

        oVertices(0) = oStartVert
        oVertices(1) = New Vertex(oStartVert.X + cdMILE_IN_METERS, oStartVert.Y)
        oVertices(2) = New Vertex(oStartVert.X + cdMILE_IN_METERS, oStartVert.Y - cdMILE_IN_METERS)
        oVertices(3) = New Vertex(oStartVert.X, oStartVert.Y - cdMILE_IN_METERS)
        oVertices(4) = oStartVert

        oCols.Add("Name", "Woofpuppy")
        Dim oRing As New RingShape(oVertices)

        oNewPoly.OuterRing = oRing

        moShapeFile.Open()
        With moShapeFile.EditTools
            .BeginTransaction()
            .Add(oNewPoly, oCols)
            .CommitTransaction()
        End With

        Return oNewPoly
    End Function
    Public Sub AddMapLayerContainer()
        Dim oPageBoundingbox As RectangleShape = GetPageBoundingBox(PrintingUnit.Inch)

        moPageLayoutMap = New MapPrinterLayer()

        moPageLayoutMap.MapUnit = GeographyUnit.Feet

        '***** Create the MapPrinterLayer and set the position
        moPageLayoutMap.BackgroundMask = AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.White, GeoColor.SimpleColors.Black, 1)

        '***** Set the maps position slightly below the pages center and 7.5 inches wide and 9 inches tall
        oPageBoundingbox = GetPageBoundingBox(PrintingUnit.Inch)
        moPageLayoutMap.SetPosition(7.5, 9, oPageBoundingbox.GetCenterPoint().X, oPageBoundingbox.GetCenterPoint().Y - 0.25, PrintingUnit.Inch)

        '***** Add the MapPrinterLayer to the PrinterInteractiveOverlay
        moPrinterOverlay.PrinterLayers.Add("MapPrinterLayer", moPageLayoutMap)


    End Sub
    Private Function GetPageBoundingBox(ByVal unit As PrintingUnit) As RectangleShape
        '***** This helper method gets the pages bounding box in the unit requested
        'Dim oPrinterOverLay As PrinterInteractiveOverLay = CType(InteractiveOverlays(mcsPRINTER_OVERLAY_NAME), PrinterInteractiveOverLay)
        'Dim oPageLayer As PagePrinterLayer = CType(oPrinterOverLay.PrinterLayers(mcsPAGE_LAYER_NAME), PagePrinterLayer)
        'Return oPageLayer.GetPosition(unit)
        Return moPrinterPage.GetPosition(unit)
    End Function
    Public Sub CreateDefaultScaleLine()
        If moPrinterOverlay.PrinterLayers.Contains("ScaleLine") Then
            moPrinterOverlay.PrinterLayers.Remove("ScaleLine")
        End If

        '***** Create the scaleLinePrinterLayer and pass in the MapPrinterLayer
        moScaleLineLayer = New ScaleLinePrinterLayer(moPageLayoutMap)

        moScaleLineLayer.MapUnit = moPageLayoutMap.MapUnit

        moScaleLineLayer.Open()
        mSetPosition(2.5, 0.25, moScaleLineLayer, EnumPagePosition.LowerLeft)

        '***** Add the ScaleLinePrinterLayer to the PrinterInteractiveOverlay
        moPrinterOverlay.PrinterLayers.Add("ScaleLine", moScaleLineLayer)
    End Sub
    Public Sub CreateDefaultScaleBar()
        If moPrinterOverlay.PrinterLayers.Contains("ScaleBar") Then
            moPrinterOverlay.PrinterLayers.Remove("ScaleBar")
        End If

        '***** Create the scaleLinePrinterLayer and pass in the MapPrinterLayer
        moScaleBarLayer = New ScaleBarPrinterLayer(moPageLayoutMap)

        With moScaleBarLayer
            .MapUnit = moPageLayoutMap.MapUnit
            .AlternateBarBrush = New GeoSolidBrush(GeoColor.SimpleColors.Black)
            '.TextColor = GeoColor.SimpleColors.Black
            '.Font = New GeoFont("Arial", 10)
            .TextStyle = New TextStyle("", New GeoFont("Arial", 10), New GeoSolidBrush(GeoColor.SimpleColors.Black))
            .BarBrush = New GeoSolidBrush(GeoColor.SimpleColors.BrightOrange)
            '.BackgroundMask = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.SimpleColors.Black, 1)
            .UnitFamily = UnitSystem.Imperial
            '.HasMask = True
            '.MaskBrush = New GeoSolidBrush(GeoColor.SimpleColors.Blue)
        End With

        moScaleBarLayer.Open()
        mSetPosition(2.5, 0.25, moScaleBarLayer, EnumPagePosition.LowerRight)

        '***** Add the ScaleLinePrinterLayer to the PrinterInteractiveOverlay
        moPrinterOverlay.PrinterLayers.Add("ScaleBar", moScaleBarLayer)
    End Sub
    Public Sub CreateDefaultScaleText()
        If moPrinterOverlay.PrinterLayers.Contains("ScaleText") Then
            moPrinterOverlay.PrinterLayers.Remove("ScaleText")
        End If

        '***** Create the scaleLinePrinterLayer and pass in the MapPrinterLayer
        moScaleTextLayer = New ScaleTextPrinterLayer(PrintingUnit.Inch, DistanceUnit.Feet, moPageLayoutMap)

        With moScaleTextLayer
            '.TextColor = GeoColor.SimpleColors.Black
            '.Font = New GeoFont("Arial", 10)
            .Font = New GeoFont("Century Gothic", 10)
            .PrinterWrapMode = PrinterWrapMode.WrapText
            .ResizeMode = PrinterResizeMode.Resizable
            .SelectabilityMode = SelectabilityMode.Selectable
            .TextBrush = New GeoSolidBrush(GeoColor.SimpleColors.Black)
        End With

        moScaleTextLayer.Open()
        mSetPosition(2.5, 0.25, moScaleTextLayer, EnumPagePosition.TopLeft)

        '***** Add the ScaleLinePrinterLayer to the PrinterInteractiveOverlay
        moPrinterOverlay.PrinterLayers.Add("ScaleText", moScaleTextLayer)
    End Sub
    Public Sub CreateMyDefaultScaleText()
        If moPrinterOverlay.PrinterLayers.Contains("MyScaleText") Then
            moPrinterOverlay.PrinterLayers.Remove("MyScaleText")
        End If

        '***** Create the scaleLinePrinterLayer and pass in the MapPrinterLayer
        'moScaleTextLayer = New MyScaleTextPrinterLayer( moPageLayoutMap, New GeoFont("Arial", 12), New Drawing.GeoSolidBrush(GeoColors.Black))
        moMyScaleTextLayer = New MyScaleTextPrinterLayer(moPageLayoutMap, New GeoFont("Arial", 12), New Drawing.GeoSolidBrush(GeoColors.Black))
        With moMyScaleTextLayer
            '.TextColor = GeoColor.SimpleColors.Black
            '.Font = New GeoFont("Arial", 10)
            .Font = New GeoFont("Century Gothic", 10)
            .PrinterWrapMode = PrinterWrapMode.WrapText
            .ResizeMode = PrinterResizeMode.Resizable
            .SelectabilityMode = SelectabilityMode.Selectable
            .TextBrush = New GeoSolidBrush(GeoColor.SimpleColors.Black)
            .ScaleDisplayMethod = MyScaleTextPrinterLayer.EnumScaleDisplayMethod.InchesFeet
        End With

        moMyScaleTextLayer.Open()
        mSetPosition(2.5, 0.25, moMyScaleTextLayer, EnumPagePosition.TopRight)

        '***** Add the ScaleLinePrinterLayer to the PrinterInteractiveOverlay
        moPrinterOverlay.PrinterLayers.Add("MyScaleText", moMyScaleTextLayer)
    End Sub

    Public Sub mSetPosition(ByVal dWidth As Double, ByVal dHeight As Double, ByVal oPrinterLayer As PrinterLayer, ByVal eInitialPosition As EnumPagePosition)
        Dim dCenterPointX As Double
        Dim dCenterPointY As Double
        Dim dDistanceFromEdge As Double = 0.25

        '***** Get the bounding box for the MapPrinterLayer
        moPageLayoutMap.Open()
        Dim oMapBoundingBox As RectangleShape = moPageLayoutMap.GetPosition(PrintingUnit.Inch)
        Select Case eInitialPosition
            Case EnumPagePosition.LowerRight
                dCenterPointX = oMapBoundingBox.LowerRightPoint.X - (dWidth / 2) - dDistanceFromEdge
                dCenterPointY = oMapBoundingBox.LowerRightPoint.Y + (dHeight / 2) + dDistanceFromEdge
            Case EnumPagePosition.LowerLeft
                dCenterPointX = oMapBoundingBox.LowerLeftPoint.X + (dWidth / 2) + dDistanceFromEdge
                dCenterPointY = oMapBoundingBox.LowerLeftPoint.Y + (dHeight / 2) + dDistanceFromEdge
            Case EnumPagePosition.TopRight
                dCenterPointX = oMapBoundingBox.UpperRightPoint.X - (dWidth / 2) - dDistanceFromEdge
                dCenterPointY = oMapBoundingBox.UpperRightPoint.Y - (dHeight / 2) - dDistanceFromEdge
            Case EnumPagePosition.TopLeft
                dCenterPointX = oMapBoundingBox.UpperLeftPoint.X + (dWidth / 2) + dDistanceFromEdge
                dCenterPointY = oMapBoundingBox.UpperLeftPoint.Y - (dHeight / 2) - dDistanceFromEdge
        End Select

        '***** Now let's try to place this layer in the lower right corner of the page
        oPrinterLayer.SetPosition(dWidth, dHeight, dCenterPointX, dCenterPointY, PrintingUnit.Inch)
    End Sub

    Private Sub btnRefresh_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnRefresh.Click
        mRefreshMapLayers()
    End Sub

    Private Sub btnProjected_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnProjected.Click

        Dim oProj4 As Proj4Projection = CType(moShapefile.FeatureSource.Projection, Proj4Projection)
        moFeatureExtent = oProj4.ConvertToInternalProjection(moFeatureExtent)

        moShapefile.FeatureSource.Projection = Nothing
        moShapefile.Open()

        moPageLayoutMap.MapUnit = GeographyUnit.Meter
        moScaleLineLayer.MapUnit = GeographyUnit.Meter
        moScaleBarLayer.MapUnit = GeographyUnit.Meter
        moScaleTextLayer.MapPrinterLayer = moPageLayoutMap

        moPageLayoutMap.MapExtent = moFeatureExtent
        moShapefile.Close()
        mRefreshMapLayers()
        btnProjected.Enabled = False
        btnGeographic.Enabled = True
    End Sub
    Private Sub btnGeographic_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnGeographic.Click

        Dim oProj4 As New Proj4Projection(Proj4Projection.GetEsriParametersString(26916), Proj4Projection.GetEsriParametersString(4269))
        oProj4.Open()
        moFeatureExtent = oProj4.ConvertToExternalProjection(moFeatureExtent)

        moShapefile.FeatureSource.Projection = oProj4
        moShapefile.Open()
        moPageLayoutMap.MapUnit = GeographyUnit.DecimalDegree
        moScaleBarLayer.MapUnit = GeographyUnit.DecimalDegree
        moScaleLineLayer.MapUnit = GeographyUnit.DecimalDegree
        moScaleTextLayer.MapPrinterLayer = moPageLayoutMap

        moPageLayoutMap.MapExtent = moFeatureExtent
        mRefreshMapLayers()
        btnProjected.Enabled = True
        btnGeographic.Enabled = False
    End Sub
    Private Sub mRefreshMapLayers()
        moPageLayoutMap.IsDrawing = True
        PageLayout.Refresh()
        moPageLayoutMap.IsDrawing = False
    End Sub
    Private Sub cboPosition_SelectionChangeCommitted(sender As Object, e As System.EventArgs) Handles cboPosition.SelectionChangeCommitted
        Dim oPosition As RectangleShape = moScaleLineLayer.GetPosition(PrintingUnit.Inch)
        Dim eNewPos As EnumCenterType
        'Select Case cboPosition.SelectedItem.ToString
        '   Case "Top Left"
        '      eNewPos = EnumPagePosition.TopLeft
        '   Case "Top Right"
        '      eNewPos = EnumPagePosition.TopRight
        '   Case "Lower Left"
        '      eNewPos = EnumPagePosition.LowerLeft
        '   Case "Lower Right"
        '      eNewPos = EnumPagePosition.LowerRight
        'End Select
        'mSetPosition(oPosition.Width, oPosition.Height, moScaleLineLayer, eNewPos)

        Select Case cboPosition.SelectedItem.ToString
            Case "Vertically"
                eNewPos = EnumCenterType.Vertical
            Case "Horizontally"
                eNewPos = EnumCenterType.Horizontal
        End Select
        mCenterElement(eNewPos, moPageLayoutMap)

    End Sub
    Private Sub mCenterElement(ByVal eCenterType As EnumCenterType, ByVal oPrinterLayer As PrinterLayer)
        Dim oCurPosition As RectangleShape = Nothing
        Dim oNewCenterPoint As PointShape

        oPrinterLayer.Open()
        oCurPosition = oPrinterLayer.GetPosition(PrintingUnit.Inch)

        Dim oPageBoundingBox As RectangleShape = GetPageBoundingBox(PrintingUnit.Inch)


        If eCenterType = EnumCenterType.Horizontal Then
            oNewCenterPoint = New PointShape(0, oCurPosition.GetCenterPoint.Y)
        Else
            oNewCenterPoint = New PointShape(oCurPosition.GetCenterPoint.X, 0)
        End If

        oPrinterLayer.SetPosition(oCurPosition.Width, oCurPosition.Height, oNewCenterPoint, PrintingUnit.Inch)


        mRefreshMapLayers()
    End Sub

    'Private Sub moPrinterOverlay_MapMouseMove(sender As Object, e As ThinkGeo.MapSuite.DesktopEdition.MapMouseMoveInteractiveOverlayEventArgs) Handles moPrinterOverlay.MapMouseMove
    '   If Not moPageLayoutMap Is Nothing Then
    '      Dim dOffsetX As Double = mGetOffsetX(PageLayout.CurrentExtent.GetCenterPoint.X)
    '      Dim dOffsetY As Double = mGetOffsetX(PageLayout.CurrentExtent.GetCenterPoint.Y)

    '      'Debug.WriteLine("X offset: " & dOffsetX)
    '      Dim dCenterX As Double = moPageLayoutMap.GetPosition(PrintingUnit.Inch).GetCenterPoint.X * 96
    '      'Debug.WriteLine("CenterX + Xoffset: " & dOffsetX + dCenterX)
    '      'Debug.WriteLine("")
    '      Dim dCenterY As Double = moPageLayoutMap.GetPosition(PrintingUnit.Inch).GetCenterPoint.Y * 96

    '      Dim dWidth As Single = CSng(moPageLayoutMap.GetPosition(PrintingUnit.Inch).Width * 96)
    '      Dim dHeight As Single = CSng(moPageLayoutMap.GetPosition(PrintingUnit.Inch).Height * 96)

    '      Debug.WriteLine(ExtentHelper.ToWorldCoordinate(moPageLayoutMap.MapExtent, CSng(e.InteractionArguments.ScreenX + dOffsetX), CSng(e.InteractionArguments.ScreenY - dOffsetY), dWidth, dHeight))
    '   End If
    'End Sub
    'Private Function mGetOffsetX(dFeet As Double) As Double
    '   Dim dWidthInFeet As Double = PageLayout.CurrentExtent.Width
    '   Dim dWidthInPixels As Double = PageLayout.Width

    '   Dim dPixels As Double = (dWidthInPixels / dWidthInFeet) * dFeet

    '   Return dPixels
    'End Function
    Private Sub btnSetScale_Click(sender As System.Object, e As System.EventArgs) Handles btnSetScale.Click
        SetScale()
    End Sub

    Private Sub btnPrint_Click(sender As System.Object, e As System.EventArgs) Handles btnPrint.Click
        Print()
    End Sub
End Class
