﻿Imports ThinkGeo.MapSuite.Drawing
Imports ThinkGeo.MapSuite.Layers
Imports ThinkGeo.MapSuite.Shapes
Imports ThinkGeo.MapSuite.Styles

<Serializable()>
Public Class MyScaleTextPrinterLayer
    Inherits LabelPrinterLayer
    <NonSerialized()>
    Public MapPrinterLayer As MapPrinterLayer
    Private Const mcsScaleTextImperial As String = " 1 in = {0} ft "
    Private Const mcsScaleTextMetric As String = " 1 cm = {0} m "
    Public Property ScaleDisplayMethod As EnumScaleDisplayMethod = EnumScaleDisplayMethod.InchesFeet

    Public Sub New(oMapPrinterLayer As MapPrinterLayer, oGeoFont As GeoFont, oBrush As GeoSolidBrush)
        MyBase.New()
        Font = oGeoFont
        TextBrush = oBrush
        MapPrinterLayer = oMapPrinterLayer
        SetText()
        PrinterWrapMode = PrinterWrapMode.AutoSizeText
        ResizeMode = PrinterResizeMode.MaintainAspectRatio

        BackgroundMask = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.White, GeoColor.SimpleColors.Black, 1)
    End Sub
    Protected Overrides Sub DrawCore(canvas As ThinkGeo.MapSuite.Drawing.GeoCanvas, labelsInAllLayers As System.Collections.ObjectModel.Collection(Of ThinkGeo.MapSuite.Styles.SimpleCandidate))
        SetText()
        MyBase.DrawCore(canvas, labelsInAllLayers)
    End Sub
    Private Sub SetText()
        Select Case ScaleDisplayMethod
            Case EnumScaleDisplayMethod.InchesFeet
                Text = String.Format(mcsScaleTextImperial, FormatScaleDisplay(GetCurrentScale(MapPrinterLayer), ScaleDisplayMethod))
            Case EnumScaleDisplayMethod.CentimetersMeter
                Text = String.Format(mcsScaleTextMetric, FormatScaleDisplay(GetCurrentScale(MapPrinterLayer), ScaleDisplayMethod))
        End Select
    End Sub
    Public Function GetCurrentScale(oMapPrinterLayer As MapPrinterLayer) As Double
        With oMapPrinterLayer
            Open()
            Dim dWidth As Single = CSng(.GetPosition().Width)
            Dim dHeight As Single = CSng(.GetPosition().Height)
            Return ExtentHelper.GetGeodesicScale(.MapExtent, dWidth, dHeight, .MapUnit)

        End With
    End Function

    Public Enum EnumScaleDisplayMethod
        Absolute = 1
        InchesFeet = 2
        CentimetersMeter = 3
        Unknown = 4
    End Enum
    Public Shared Function FormatScaleDisplay(ByVal dScale As Double, Optional eDisplayMethod As EnumScaleDisplayMethod = EnumScaleDisplayMethod.Unknown) As String
        Dim sFormattedScale As String = String.Empty
        Dim sFormat As String

        If eDisplayMethod = EnumScaleDisplayMethod.Unknown Then
            eDisplayMethod = Form1.ScaleDisplayMethod
        End If

        Select Case eDisplayMethod
            Case EnumScaleDisplayMethod.Absolute
                sFormattedScale = String.Format("1:{0:#,###}", dScale)
            Case EnumScaleDisplayMethod.CentimetersMeter
                If dScale / 100 >= 1 Then
                    sFormat = "{0:#,###}"
                Else
                    sFormat = "{0:0.00}"
                End If
                sFormattedScale = String.Format(sFormat, (dScale / 100))
            Case EnumScaleDisplayMethod.InchesFeet
                If dScale / 12 >= 1 Then
                    sFormat = "{0:#,###}"
                Else
                    sFormat = "{0:0.00}"
                End If
                sFormattedScale = String.Format(sFormat, (dScale / 12))
        End Select

        Return sFormattedScale
    End Function

End Class
